aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'pmstestsuite/library/standard/ext_cases.py')
-rw-r--r--pmstestsuite/library/standard/ext_cases.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/pmstestsuite/library/standard/ext_cases.py b/pmstestsuite/library/standard/ext_cases.py
index 94a93cc..8fcbf12 100644
--- a/pmstestsuite/library/standard/ext_cases.py
+++ b/pmstestsuite/library/standard/ext_cases.py
@@ -2,16 +2,16 @@
# (c) 2011 Michał Górny <mgorny@gentoo.org>
# Released under the terms of the 2-clause BSD license.
-from .dbus_case import DBusEbuildTestCase
+from pmstestsuite.library.case import EbuildTestCase
-class DBusFetchingEbuildTestCase(DBusEbuildTestCase):
+class FetchingEbuildTestCase(EbuildTestCase):
"""
A DBusEbuildTestCase variant with a standarized way of fetching
sources -- to decrease {${DISTDIR}} pollution.
"""
def __init__(self, *args, **kwargs):
- DBusEbuildTestCase.__init__(self, *args, **kwargs)
+ EbuildTestCase.__init__(self, *args, **kwargs)
val = 'http://dev.gentoo.org/~mgorny/pmsts-temp.bin'
if 'SRC_URI' in self.ebuild_vars:
val = '%s %s' % (self.ebuild_vars['SRC_URI'], val)
@@ -2,16 +2,16 @@
"""
- A DBusEbuildTestCase variant with a standarized way of fetching
+ A EbuildTestCase variant with a standarized way of fetching
sources -- to decrease {${DISTDIR}} pollution.
"""